@@ -18,7 +18,7 @@
 #' @param colRef the column number where the test statistic of interest can be found
 #' in the standard \code{anova} output when calling \code{anova(objectNull,object)}.
 #' Default choices have been set for common models (\code{colRef=5} for \code{lm} objects,
-#' \code{colRef=6} for \code{lmer} objects and \code{colRef=4} otherwise, which is correct 
+#' \code{colRef=6} for \code{lmer} and \code{glmmTMB} objects and \code{colRef=4} otherwise, which is correct 
 #' for \code{glm} and \code{gam} objects).
 #' @param ncpus the number of CPUs to use. Default (NULL) uses two less than the total 
 #' available.
@@ -81,7 +81,7 @@
 #' @importFrom methods .hasSlot
 
 #' @export
-anovaPB=function(objectNull, object, n.sim=999, colRef = switch(class(object)[1],"lm"=5,"lmerMod"=6,4), rowRef=2, ncpus=NULL, ...)
+anovaPB=function(objectNull, object, n.sim=999, colRef = switch(class(object)[1],"lm"=5,"lmerMod"=6,"glmmTMB"=6,4), rowRef=2, ncpus=NULL, ...)
 {
   # check the second model is the larger one... otherwise this will be a prob later
   if(length(unlist(coef(objectNull)))>length(unlist(coef(object))))
@@ -221,7 +221,7 @@ anovaPB=function(objectNull, object, n.sim=999, colRef = switch(class(object)[1]
   if(ncpus>1)
   {
     cl <- parallel::makeCluster(ncpus)
-    parallel::clusterExport(cl,c("getStat","anovaFn","yNew","objectNull","object","modelF","is.mva","fm.update","whichResp",
+    parallel::clusterExport(cl,c("getStat","anovaFn","yNew","objectNull","object","modelF","is.mva","fm.update","whichResp","nbinom2",
                                "respDimnames","rowRef","colRef",as.character(cll[[1]])), envir=environment())
     statList <- parallel::clusterApplyLB(cl, 1:n.sim, getStat, yNew=yNew, objectNull=objectNull, object=object, modelF=modelF,
                                          anovaFn=anovaFn, is.mva=is.mva, fm.update=fm.update, whichResp=whichResp, 
